==> adms-2.2.4.tar.gz: adms-2.2.4/admsFile/admsFile.h <==
/*
 * RCS Info
 * $Id: admsFile.h,v 1.10 2005/05/09 14:38:30 r29173 Exp $
 * 
 * Log
 * $Log: admsFile.h,v $
 * Revision 1.10  2005/05/09 14:38:30  r29173
 * cleaned-up source directory structure
 *
 * Revision 1.9  2005/05/03 09:35:15  r29173
 * cleaned-up header file dependencies
 *
 * Revision 1.8  2005/05/03 07:58:20  r29173
 * moved admsNS into admsFile
 *
 * Revision 1.7  2004/11/19 12:29:56  r29173
 * renamed _C into CAT
 * saved argc, argv into admsmain element
 * added adms:setenv transform
 *
 * Revision 1.6  2004/10/13 15:24:13  r29173
 * preprocess xml files passed to admsXml with adms_file_getpathname
 *
 * Revision 1.5  2004/09/23 16:20:47  r29173
 * create automatically standard vams files when missing.
 *
 * Revision 1.4  2004/08/19 16:43:13  r29173
 * cleaned-up i/o file handling
 *
 * Revision 1.3  2004/08/03 12:33:54  r29173
 * import adms-1.21.0 from local CVS
 *
 * Revision 1.2  2004/05/26 13:02:48  r29173
 * added default values to all enumerations
 *
 * Revision 1.1.1.1  2004/05/21 12:20:01  r29173
 * recreated cvs data structure (crashed after revision 1.13.0!)
 *
 * Revision 1.11  2004/03/08 13:58:05  r29173
 * all code lower-cased
 *
 * Revision 1.10  2004/02/19 17:02:37  r29173
 * started implementing code builder in yacc parser
 *
 * Revision 1.9  2004/01/13 11:26:15  r29173
 * added adms_message_usage
 *
 * Revision 1.8  2004/01/09 16:23:46  r29173
 * cleaned-up use of #include
 *
 * Revision 1.7  2004/01/06 14:13:12  r29173
 * fixed definition of win32_interface
 *
 * Revision 1.6  2004/01/06 12:35:10  r29173
 * fixed the use of globals: input file and output file
 *
 * Revision 1.5  2004/01/05 11:38:17  r29173
 * removed unused code
 *
 * Revision 1.4  2003/12/11 16:10:10  r29173
 * changed usage of win32_interface
 *
 * Revision 1.3  2003/12/11 16:01:53  r29173
 * changed prefix [epst]_adms_ to [epst]_
 *
 * Revision 1.2  2003/05/21 14:18:01  r29173
 * add rcs info
 *
 */

#ifndef _adms_file_included
#define _adms_file_included

#include <admsObject/admsH.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsFile)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

typedef void  (t_file_usage) (void);
typedef void  (*p_file_usage) (void);
#define _t_file_usage_static(function) static void  ((function)) (void)

win32_interface gboolean adms_file_print_usage (const p_file_usage usage);
win32_interface gboolean adms_file_check_command_line (const int argc, const char **argv, const p_file_usage usage);
win32_interface gboolean adms_file_filehandling_print(const char *str);

win32_interface GSList *adms_file_get_ifile_from_argv(const int argc, const char **argv);
win32_interface GSList *adms_file_get_ipath_from_argv(const int argc, const char **argv);

win32_interface GSList *adms_file_get_program_from_argv(const int argc, const char **argv);

win32_interface char *adms_file_getpathname(const char *name);
win32_interface FILE *adms_file_open_read (const char *fileName, const char *message);
win32_interface FILE *adms_file_open_read_with_path (const char *fileName,GSList * path);
win32_interface FILE *adms_file_open_write (const char *fileName, const char *message);

win32_interface void  adms_file_close_output(void);
win32_interface void  adms_file_setfile_output (FILE *ofh);
win32_interface FILE *adms_file_getfile_output (void);
win32_interface char *adms_path_get_basename (const char *name);


#endif /* _adms_file_included */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsFile/admsFile.h <==
/*
 * RCS Info
 * $Id: admsFile.h 528 2007-02-09 19:41:36Z r29173 $
 * 
 * Log
 * $Log$
 * Revision 1.10  2005/05/09 14:38:30  r29173
 * cleaned-up source directory structure
 *
 * Revision 1.9  2005/05/03 09:35:15  r29173
 * cleaned-up header file dependencies
 *
 * Revision 1.8  2005/05/03 07:58:20  r29173
 * moved admsNS into admsFile
 *
 * Revision 1.7  2004/11/19 12:29:56  r29173
 * renamed _C into CAT
 * saved argc, argv into admsmain element
 * added adms:setenv transform
 *
 * Revision 1.6  2004/10/13 15:24:13  r29173
 * preprocess xml files passed to admsXml with adms_file_unixify
 *
 * Revision 1.5  2004/09/23 16:20:47  r29173
 * create automatically standard vams files when missing.
 *
 * Revision 1.4  2004/08/19 16:43:13  r29173
 * cleaned-up i/o file handling
 *
 * Revision 1.3  2004/08/03 12:33:54  r29173
 * import adms-1.21.0 from local CVS
 *
 * Revision 1.2  2004/05/26 13:02:48  r29173
 * added default values to all enumerations
 *
 * Revision 1.1.1.1  2004/05/21 12:20:01  r29173
 * recreated cvs data structure (crashed after revision 1.13.0!)
 *
 * Revision 1.11  2004/03/08 13:58:05  r29173
 * all code lower-cased
 *
 * Revision 1.10  2004/02/19 17:02:37  r29173
 * started implementing code builder in yacc parser
 *
 * Revision 1.9  2004/01/13 11:26:15  r29173
 * added adms_message_usage
 *
 * Revision 1.8  2004/01/09 16:23:46  r29173
 * cleaned-up use of #include
 *
 * Revision 1.7  2004/01/06 14:13:12  r29173
 * fixed definition of win32_interface
 *
 * Revision 1.6  2004/01/06 12:35:10  r29173
 * fixed the use of globals: input file and output file
 *
 * Revision 1.5  2004/01/05 11:38:17  r29173
 * removed unused code
 *
 * Revision 1.4  2003/12/11 16:10:10  r29173
 * changed usage of win32_interface
 *
 * Revision 1.3  2003/12/11 16:01:53  r29173
 * changed prefix [epst]_adms_ to [epst]_
 *
 * Revision 1.2  2003/05/21 14:18:01  r29173
 * add rcs info
 *
 */

#ifndef _adms_file_included
#define _adms_file_included

#include <admsObject/admsH.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsFile)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface void adms_file_setfile_output (FILE *ofh);
win32_interface void  adms_file_close_output(void);
win32_interface int adms_file_filehandling_print(const char *str);

win32_interface FILE *adms_file_open_read (const char *fileName);
win32_interface FILE *adms_file_open_read_with_path (const char *fileName,p_slist path);
win32_interface FILE *adms_file_open_write (const char *fileName);

#endif /* _adms_file_included */
